@@ -1,5 +1,5 @@
 #######################################################################
-# $Id: TriangularNumber.pm,v 1.18 2010-11-26 21:07:38 dpchrist Exp $
+# $Id: TriangularNumber.pm,v 1.19 2010-11-27 03:38:00 dpchrist Exp $
 
 =head1 NAME
 
@@ -12,7 +12,7 @@ See the script t/example.t:
 
     2010-07-02 21:43:34 dpchrist@p43400e ~/Dpchrist-TriangularNumber
     $ cat t/example.t 
-    # $Id: TriangularNumber.pm,v 1.18 2010-11-26 21:07:38 dpchrist Exp $
+    # $Id: TriangularNumber.pm,v 1.19 2010-11-27 03:38:00 dpchrist Exp $
     # Copyright 2010 by David Christensen dpchrist@holgerdanske.com
 
     use Test::More tests => 1;
@@ -43,7 +43,7 @@ Output:
 
 =head1 DESCRIPTION
 
-This documentation describes module revision $Revision: 1.18 $.
+This documentation describes module revision $Revision: 1.19 $.
 
 
 This is alpha test level software
@@ -127,7 +127,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw();
 
-our $VERSION = sprintf("%d.%03d", q$Revision: 1.18 $ =~ /(\d+)/g);
+our $VERSION = sprintf("%d.%03d", q$Revision: 1.19 $ =~ /(\d+)/g);
 
 #######################################################################
 
@@ -225,16 +225,34 @@ __END__
 # remaining pod:
 #----------------------------------------------------------------------
 
-=pod
-
 =head1 INSTALLATION
 
-To install this module type the following:
+Old school:
 
-   perl Makefile.PL
-   make
-   make test
-   make install
+    $ perl Makefile.PL
+    $ make    
+    $ make test
+    $ make install 
+
+Minimal:
+
+    $ cpan Dpchrist::TriangularNumber
+
+Complete:
+
+    $ cpan Bundle::Dpchrist
+
+The following warning may be safely ignored:
+
+    Can't locate Dpchrist/Module/MakefilePL.pm in @INC (@INC contains: /
+    etc/perl /usr/local/lib/perl/5.10.0 /usr/local/share/perl/5.10.0 /us
+    r/lib/perl5 /usr/share/perl5 /usr/lib/perl/5.10 /usr/share/perl/5.10
+    /usr/local/lib/site_perl .) at Makefile.PL line 22.
+
+
+=head2 PREREQUISITES
+
+See Makefile.PL in the source distribution root directory.
 
 
 =head1 SEE ALSO
